#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: urls.py 9589 2016-03-14 07:45:28Z Judy $
#
# Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Judy $
# $Date: 2016-03-14 15:45:28 +0800 (一, 14  3 2016) $
# $Revision: 9589 $

from django.conf import settings
from django.conf.urls import url, include, patterns

#import views

urlpatterns = patterns('', )

# Newsletter_extension api
if 'Theophrastus.newsletter_extension' in settings.INSTALLED_APPS:
    urlpatterns += (
        url(r'', include('Theophrastus.newsletter_extension.urls.api')),
    )

# Integration api
if 'Theophrastus.integration' in settings.INSTALLED_APPS:
    urlpatterns += (
        url(r'', include('Theophrastus.integration.urls.api')),
    )
